**Note**
This is not the full [MetricFlow](https://github.com/transform-data/metricflow/) package, this is MetricFlow-Lite. MetricFlow-Lite is a forked version of MetricFlow with some deps removed.

**Warning**
MetricFlow-Lite is not supported. I.e., issues/bugs/change requests should happen on the full [MetricFlow](https://github.com/transform-data/metricflow/) pacakge. 

# Welcome to MetricFlow-Lite

MetricFlow-Lite is a forked version of MetricFlow with data warehouse connector dependencies removed. This necessary for some of our (Transform) internal projects. 

## License

MetricFlow-Lite is open source software. The project relies on several licenses including AGPL-3.0-or-later and Apache (specified at folder level).

MetricFlow-Lite is built by [Transform](https://transform.co/)
